<?php
/**
 * Clase ColaboradorBL
 *
 * @package    
 * @subpackage 
 * @author     ColaboradorBL
 * @version    SVN: $Id: ColaboradorBL.class.php,v 1.1 2008/02/08 21:56:44 william.taype Exp $ 
 */
class ColaboradorBL{
    
  /**
  * 
  *
  * @param $o_ColaboradorBean, objeto de tipo Colaborador 
  * @return Boolean
  */
  public function busquedaColaborador(ColaboradorBean $o_ColaboradorBean){
    
    $o_ColaboradorDP = new ColaboradorDP($o_ColaboradorBean);
    if($o_ColaboradorBean->getIdColaborador()){
      return $o_ColaboradorDP->selectByPk();
    }else{
      return $o_ColaboradorDP->select();
    }
    
  }
   
  public function busquedaColaboradorResulset(ColaboradorBean $o_ColaboradorBean){
    
    $o_ColaboradorDP = new ColaboradorDP($o_ColaboradorBean);
    return $o_ColaboradorDP->selectResultset();
        
  }
  
  public function insertarColaborador(ColaboradorBean $o_ColaboradorBean){
    
    $o_ColaboradorCT = new ColaboradorCT();
    return $o_ColaboradorCT->guardar($o_ColaboradorBean);
    
  }
  public function modificarColaborador(ColaboradorBean $o_ColaboradorBean){
      $o_ColaboradorCT = new ColaboradorCT();
      return $o_ColaboradorCT->modificar($o_ColaboradorBean);
  }
  /**
	* Función que retorna un objeto Colaborador o una lista de Objetos de Colaborador,
	* dependiendo del parametro que se le envia si este contiene o no el Id de Colaborador
	*
	* @param $o_ColaboradorBean, es un objeto de tipo Colaborador
	* @return Object
	*/
	public function modificarEstadoColaborador(ColaboradorBean $o_ColaboradorBean){
	  
	}
  
  public function eliminarColaborador(ColaboradorBean $o_ColaboradorBean){
    $o_ColaboradorCT = new ColaboradorCT();
    return $o_ColaboradorCT->eliminar($o_ColaboradorBean);
    
  }
  
  public function getCountResult(ColaboradorBean $o_ColaboradorBean){
    $o_ColaboradorCT = new ColaboradorCT();
    return $o_ColaboradorCT->totalRegistros($o_ColaboradorBean);
  }
  
}?>